"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MiddlewareClient = void 0;
const client_utils_1 = require("@scramjet/client-utils");
const manager_api_client_1 = require("@scramjet/manager-api-client");
class MiddlewareClient {
    constructor(apiBase, utils = new client_utils_1.ClientUtils(apiBase)) {
        this.apiBase = apiBase.replace(/\/$/, "");
        this.client = utils;
    }
    getManagerClient(id, mutliManagerApiBase = "/api/v1") {
        return new manager_api_client_1.ManagerClient(`${this.apiBase}/space/${id}${mutliManagerApiBase}`);
    }
    async getManagers() {
        return this.client.get("spaces");
    }
    async getVersion() {
        return this.client.get("version");
    }
    async getAuditStream() {
        return this.client.getStream("audit");
    }
    async listAccessKeys(spaceId) {
        return this.client.get(`space/${spaceId}/apikey`, {
            headers: { "content-type": "application/json" },
        });
    }
    async createAccessKey(spaceId, opts) {
        var _a;
        return this.client.post(`space/${spaceId}/apikey`, {
            description: (_a = opts.description) === null || _a === void 0 ? void 0 : _a.trim()
        }, {
            headers: { "content-type": "application/json" },
        }, { json: true, parse: "json" });
    }
    async revokeAccessKey(spaceId, accessKey) {
        return this.client.delete(`space/${spaceId}/apikey`, {
            headers: {
                "content-type": "application/json",
                "x-revoke": accessKey
            }
        });
    }
    async revokeAllAccessKeys(spaceId, apiKeys) {
        for (const key of apiKeys.accessKeys) {
            try {
                await this.revokeAccessKey(spaceId, key.created.toString());
            }
            catch (_e) {
                throw new Error("Unable to revoke access keys");
            }
        }
        return {
            message: "Keys successfully revoked",
            keysRevoked: apiKeys.accessKeys.length
        };
    }
}
exports.MiddlewareClient = MiddlewareClient;
//# sourceMappingURL=middleware-client.js.map